@@ -1,14 +1,20 @@
 /*
- * Copyright Valkey Contributors.
+ * Copyright (c) Valkey Contributors
  * All rights reserved.
- * SPDX-License-Identifier: BSD 3-Clause
+ * SPDX-License-Identifier: BSD-3-Clause
  */
-
 #include "cluster_slot_stats.h"
 
 #define UNASSIGNED_SLOT 0
 
-typedef enum { KEY_COUNT, CPU_USEC, NETWORK_BYTES_IN, NETWORK_BYTES_OUT, SLOT_STAT_COUNT, INVALID } slotStatType;
+typedef enum {
+    KEY_COUNT,
+    CPU_USEC,
+    NETWORK_BYTES_IN,
+    NETWORK_BYTES_OUT,
+    SLOT_STAT_COUNT,
+    INVALID
+} slotStatType;
 
 /* -----------------------------------------------------------------------------
  * CLUSTER SLOT-STATS command
@@ -276,8 +282,8 @@ void clusterSlotStatsCommand(client *c) {
     if (c->argc == 5 && !strcasecmp(c->argv[2]->ptr, "slotsrange")) {
         /* CLUSTER SLOT-STATS SLOTSRANGE start-slot end-slot */
         int startslot, endslot;
-        if ((startslot = getSlotOrReply(c, c->argv[3])) == C_ERR ||
-            (endslot = getSlotOrReply(c, c->argv[4])) == C_ERR) {
+        if ((startslot = getSlotOrReply(c, c->argv[3])) == -1 ||
+            (endslot = getSlotOrReply(c, c->argv[4])) == -1) {
             return;
         }
         if (startslot > endslot) {
