@@ -582,6 +582,56 @@ if {[string match {*jemalloc*} [s mem_allocator]]} {
       set err1
     } {*WRONGTYPE*}
 
+    test "SET with IFEQ conditional" {
+        r del foo
+
+        r set foo "initial_value"
+
+        assert_equal {OK} [r set foo "new_value" ifeq "initial_value"]
+        assert_equal "new_value" [r get foo]
+
+        assert_equal {} [r set foo "should_not_set" ifeq "wrong_value"]
+        assert_equal "new_value" [r get foo]
+    }
+
+    test "SET with IFEQ conditional - non-string current value" {
+        r del foo
+
+        r sadd foo "some_set_value"
+        assert_error {WRONGTYPE Operation against a key holding the wrong kind of value} {r set foo "new_value" ifeq "some_set_value"}
+    }
+
+
+    test "SET with IFEQ conditional - with get" {
+        r del foo
+
+        assert_equal {} [r set foo "new_value" ifeq "initial_value" get]
+        assert_equal {} [r get foo]
+
+        r set foo "initial_value"
+
+        assert_equal "initial_value" [r set foo "new_value" ifeq "initial_value" get]
+        assert_equal "new_value" [r get foo]
+    }
+
+    test "SET with IFEQ conditional - non string current value with get" {
+        r del foo
+
+        r sadd foo "some_set_value"
+
+        assert_error {WRONGTYPE Operation against a key holding the wrong kind of value} {r set foo "new_value" ifeq "initial_value" get}
+    }
+
+    test "SET with IFEQ conditional - with xx" {
+        r del foo
+        assert_error {ERR syntax error} {r set foo "new_value" ifeq "initial_value" xx}
+    }
+
+    test "SET with IFEQ conditional - with nx" {
+        r del foo
+        assert_error {ERR syntax error} {r set foo "new_value" ifeq "initial_value" nx}
+    }
+
     test {Extended SET EX option} {
         r del foo
         r set foo bar ex 10
@@ -705,4 +755,31 @@ if {[string match {*jemalloc*} [s mem_allocator]]} {
         assert_encoding "int" bar
         lappend res [r get bar]
     } {12 12}
+
+if {[string match {*jemalloc*} [s mem_allocator]]} {
+    test {Memory usage of embedded string value} {
+        # Check that we can fit 9 bytes of key + value into a 32 byte
+        # allocation, including the serverObject itself.
+        r set quux xyzzy
+        assert_lessthan_equal [r memory usage quux] 32
+
+        # Check that the SDS overhead of the embedded key and value is 6 bytes
+        # (sds5 + sds8). This is the memory layout:
+        #
+        # +--------------+--------------+---------------+----------------+
+        # | serverObject |              | sds5 key      | sds8 value     |
+        # | header       | key-hdr-size | hdr "quux" \0 | hdr "xyzzy" \0 |
+        # | 16 bytes     | 1            | 1  + 4    + 1 | 3  + 5     + 1 |
+        # +--------------+--------------+---------------+----------------+
+        #
+        set content_size [expr {[string length quux] + [string length xyzzy]}]
+        regexp {robj:(\d+)} [r debug structsize] _ obj_header_size
+        set debug_sdslen [r debug sdslen quux]
+        regexp {key_sds_len:4 key_sds_avail:0 obj_alloc:(\d+)} $debug_sdslen _ obj_alloc
+        regexp {val_sds_len:5 val_sds_avail:(\d+) val_alloc:(\d+)} $debug_sdslen _ avail val_alloc
+        set sds_overhead [expr {$obj_alloc + $val_alloc - $obj_header_size - 1 - $content_size - $avail}]
+        assert_equal 6 $sds_overhead
+    } {} {needs:debug}
+} ; # if jemalloc
+
 }
